@@ -2,7 +2,7 @@
 # validator.py
 # Data Culpa Validator Python Client
 #
-# Copyright (c) 2020-2021 Data Culpa, Inc.
+# Copyright (c) 2020-2022 Data Culpa, Inc.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to 
@@ -111,9 +111,9 @@ class DataCulpaValidator:
                  watchpoint_environment="default",
                  watchpoint_stage="default",
                  watchpoint_version="default",
-                 protocol="http", 
+                 protocol="https",      # https for *.dataculpa.cloud hosts
                  dc_host="localhost", 
-                 dc_port=7777, 
+                 dc_port=7778,          # 7778 for *.dataculpa.cloud hosts; on-prem might be 7777 depending on your configuration.
                  api_access_id=None, 
                  api_secret=None,
                  queue_window=20,
@@ -379,8 +379,9 @@ class DataCulpaValidator:
 
         return self._pipeline_id
 
-    def get_config(self):
-        _id = self._get_pipeline_id()
+    def get_config(self, _id=None):
+        if _id is None:
+            _id = self._get_pipeline_id()
 
         if _id is not None:
             # now we can get the config...
@@ -465,6 +466,10 @@ class DataCulpaValidator:
         """
         Send the raw file contents to Validator and commit the queue.
         """
+        if self._queue_id is None:
+            self._open_queue() #"queue_id is not set; call open_queue first"
+            assert self._queue_id is not None, "error opening queue"
+
         post_url = self._get_base_url("batch-validate/%s" % self._queue_id)
 
         if headers is None:
@@ -726,6 +731,7 @@ class DataCulpaValidator:
 
         p = { "api_key": self.api_access_id, "secret": self.api_secret }
         js = json.dumps(p)
+        
         # need to catch DataCulpaBadServerCodeError and look at 401 here...
         r = self.POST(login_url, js, is_login=True)
         jr = self._parseJson(login_url, r.content)
@@ -736,6 +742,13 @@ class DataCulpaValidator:
     def test_login(self):
         test_url = self._get_base_url("auth/test-login")
 
+    def get_logs(self, pipeline_id=None):
+        if pipeline_id is None:
+            pipeline_id = self._get_pipeline_id()
+        url = self._get_base_url("data/watchpoint-logs/%s" % pipeline_id)
+        r = self.GET(url)
+        return self._parseJson(url, r.content)
+
     def watchpoint_log_message(self, msg):
         return self.watchpoint_lograw({'message': msg})
 
